@@ -39,8 +39,8 @@ documentation of the distribution modules to get more informations about all pos
 =head1 MOTIVATION
 
 My motivation is very simple. Every linux administrator knows the well-known tool sar of sysstat.
-It helps me a lot of time to search for system bottlenecks and to solve problems but it's hard to
-parse the output and to store different statistics into a database. So I though to develope
+It helps me a lot of time to search for system bottlenecks and to solve problems, but it's hard to
+parse the output if you want to store the statistics into a database. So I thought to develope
 Sys::Statistics::Linux. It's not a replacement but it should make it simpler to you to write your
 own system monitor.
 
@@ -49,31 +49,34 @@ If Sys::Statistics::Linux doesn't provide statistics that are strongly needed th
 =head1 TECHNICAL NOTE
 
 This distribution collects statistics by the virtual F</proc> filesystem (procfs) and is
-developed on default vanilla kernels. It is tested on x86 hardware with the distributions RHEL,
+developed on the default vanilla kernel. It is tested on x86 hardware with the distributions RHEL,
 Fedora, Debian, Ubuntu, Asianux, Slackware, Mandriva, SuSE (SuSE on s390 and s390x architecture
-as well but a long time ago) and openSUSE on kernel versions 2.4 and/or 2.6 and should run on all
-linux kernels with a default vanilla kernel as well. It's possible that it doesn't run on all linux
-distributions if some procfs features are deactivated or too much modified. As example the linux
-kernel 2.4 can compiled with the option C<CONFIG_BLK_STATS> what turn on or off block statistics
-for devices.
+as well but a long time ago) and openSUSE on kernel versions 2.4 and/or 2.6. It's possible that
+it doesn't run on all linux distributions if some procfs features are deactivated or too much
+modified. As example the linux kernel 2.4 can compiled with the option C<CONFIG_BLK_STATS> what
+turn on or off block statistics for devices.
 
 =head1 DELTAS
 
 The statistics for C<CpuStats>, C<ProcStats>, C<PgSwStats>, C<NetStats>, C<DiskStats> and C<Processes>
-are deltas, for this reason it's necessary to initialize the statistics first before the data
-can be prepared by C<get()>. These statistics can be initialized with the methods C<new()>,
-C<set()> and C<init()>. Any option that is set to 1 will be initialized by the call of C<new()>
-or C<set()>. The call of init() re-initialize all statistics that are set to 1 or 2. By the call
-of C<get()> the initial statistics will be updated automatically. Please refer the METHOD section
-to get more information about the calls of C<new()>, C<set()>, C<init()> and C<get()>.
+are deltas, for this reason it's necessary to initialize the statistics before the data can be
+prepared by C<get()>. These statistics can be initialized with the methods C<new()>, C<set()> and
+C<init()>. Any option that is set to 1 will be initialized by the call of C<new()> or C<set()>.
+The call of init() re-initialize all statistics that are set to 1 or 2. By the call of C<get()>
+the initial statistics will be updated automatically. Please refer the section L</METHODS> to get more
+information about the calls of C<new()>, C<set()>, C<init()> and C<get()>.
 
-Another exigence is to sleep for while - at least for one second - before the call of C<get()>
+Another exigence is to sleep for a while - at least for one second - before the call of C<get()>
 if you want to get useful statistics. The statistics for C<SysInfo>, C<MemStats>, C<SockStats>,
 C<DiskUsage>, C<LoadAVG> and C<FileStats> are no deltas. If you need only one of these informations
 you don't need to sleep before the call of C<get()>.
 
 The method C<get()> prepares all requested statistics and returns the statistics as a
-C<Sys::Statistics::Linux::Compilation> object. The inital statistics will be updated.
+L<Sys::Statistics::Linux::Compilation> object. The inital statistics will be updated.
+
+=head1 MANUAL PROC(5)
+
+The L<<a href="http://www.kernel.org/doc/man-pages/online/pages/man5/proc.5.html">Linux Programmer's Manual</a>>.
 
 =head1 OPTIONS
 
@@ -87,7 +90,7 @@ The options must be set with one of the following values:
     1 - activate and init statistics
     2 - activate statistics but don't init
 
-In addition it's possible to handoff a process list for option C<Processes>.
+In addition it's possible to pass a process list for option C<Processes>.
 
     my $lxs = Sys::Statistics::Linux->new(
         processes => {
@@ -116,7 +119,7 @@ To get more informations about the statistics refer the different modules of the
 =head2 new()
 
 Call C<new()> to create a new Sys::Statistics::Linux object. You can call C<new()> with options.
-This options would be handoff to the method C<set()>.
+This options would be passed to the method C<set()>.
 
 Without options
 
@@ -141,9 +144,10 @@ It's possible to call C<new()> with a hash reference of options.
 
 =head2 set()
 
-Call C<set()> to activate or deactivate options. The following example would call C<new()> and
-C<init()> of C<Sys::Statistics::Linux::CpuStats> and delete the object of
-C<Sys::Statistics::Linux::SysInfo>:
+Call C<set()> to activate or deactivate options.
+
+The following example would call C<new()> and initialize C<Sys::Statistics::Linux::CpuStats>
+and delete the object of C<Sys::Statistics::Linux::SysInfo>.
 
     $lxs->set(
         processes =>  0, # deactivate this statistic
@@ -162,7 +166,8 @@ It's possible to call C<set()> with a hash reference of options.
 
 =head2 get()
 
-Call C<get()> to get the collected statistics. C<get()> returns a Sys::Statistics::Linux::Compilation object.
+Call C<get()> to get the collected statistics. C<get()> returns a L<Sys::Statistics::Linux::Compilation>
+object.
 
     my $stat = $lxs->get;
 
@@ -174,13 +179,13 @@ Now the statistcs are available with
 
     $stat->{cpustats}
 
-Take a look to the documentation of C<Sys::Statistics::Linux::Compilation> for more informations.
+Take a look to the documentation of L<Sys::Statistics::Linux::Compilation> for more informations.
 
 =head2 init()
 
-The call of init() initiate all activated statistics that are necessary for deltas. That could be helpful
-if your script runs in a endless loop with a high sleep interval. Don't forget that if you call C<get()>
-that the statistics are average values since the last time they were initiated.
+The call of C<init()> initiate all activated statistics that are necessary for deltas. That could
+be helpful if your script runs in a endless loop with a high sleep interval. Don't forget that if
+you call C<get()> that the statistics are deltas since the last time they were initiated.
 
 The following example would calculate average statistics for 30 minutes:
 
@@ -259,9 +264,9 @@ Set and get a time stamp:
 
     my $lxs = Sys::Statistics::Linux->new();
     $lxs->settime('%Y/%m/%d %H:%M:%S');
-    print "$lxs->gettime\n";
+    print $lxs->gettime, "\n";
 
-If you're not sure you can use the the C<Data::Dumper> module to learn more about the hash structure:
+If you want to know how the data looks like you can use C<Data::Dumper> to check it:
 
     use strict;
     use warnings;
@@ -274,7 +279,7 @@ If you're not sure you can use the the C<Data::Dumper> module to learn more abou
 
     print Dumper($stat);
 
-How to get processes with the highest cpu workload:
+How to get the top 5 processes with the highest cpu workload:
 
     use strict;
     use warnings;
@@ -283,18 +288,12 @@ How to get processes with the highest cpu workload:
     my $lxs = Sys::Statistics::Linux->new( processes => 1 );
     sleep(1);
     my $stat = $lxs->get;
-    my $proc = $stat->processes;
-
-    my @top5 = (
-       map  { $_->[0] }
-       reverse sort { $a->[1] <=> $b->[1] }
-       map  { [ $_, $procs->{$_}->{ttime} ] } keys %{$proc}
-    )[0..4];
+    my @top5 = $stat->pstop( ttime => 5 );
 
 =head1 BACKWARD COMPATIBILITY
 
 The old options and keys - CpuStats, NetStats, etc - are still available together but deprecated!
-It's not possible to access the statistics via C<Sys::Statistics::Linux::Compilation> and it's
+It's not possible to access the statistics via L<Sys::Statistics::Linux::Compilation> and it's
 not possible to call C<search()> and C<psfind()> if you use the old options.
 
 You should use the new options and access the statistics over the accessors
@@ -307,10 +306,12 @@ or direct
 
 =head1 PREREQUISITES
 
+    Carp
+    POSIX
+    Test::More
+    Time::HiRes
     UNIVERSAL
     UNIVERSAL::require
-    Test::More
-    Carp
 
 =head1 EXPORTS
 
@@ -337,7 +338,7 @@ This program is free software; you can redistribute it and/or modify it under th
 =cut
 
 package Sys::Statistics::Linux;
-our $VERSION = '0.26_01';
+our $VERSION = '0.35_01';
 
 use strict;
 use warnings;
@@ -347,6 +348,9 @@ use UNIVERSAL;
 use UNIVERSAL::require;
 use Sys::Statistics::Linux::Compilation;
 
+# save loaded modules
+my %MODS;
+
 sub new {
     my $class = shift;
     my @options = qw(
@@ -355,10 +359,12 @@ sub new {
         SockStats DiskStats DiskUsage
         LoadAVG   FileStats Processes
     );
-    my $self = bless { obj  => { }, mods => { } }, $class; 
+    my $self = bless { obj => { } }, $class; 
     foreach my $opt (@options) {
+        # backward compatibility
         $self->{opts}->{$opt} = 0;
         $self->{maps}->{$opt} = $opt;
+        # new style
         my $lcopt = lc($opt);
         $self->{opts}->{$lcopt} = 0;
         $self->{maps}->{$lcopt} = $opt;
@@ -373,7 +379,6 @@ sub set {
     my $args  = ref($_[0]) eq 'HASH' ? shift : {@_};
     my $opts  = $self->{opts};
     my $obj   = $self->{obj};
-    my $mods  = $self->{mods};
     my $maps  = $self->{maps};
     my $pids  = ();
 
@@ -396,9 +401,9 @@ sub set {
             my $package = $class.'::'.$maps->{$opt};
 
             # require mod if not loaded
-            unless ($mods->{$package}) {
+            unless ($MODS{$package}) {
                 $package->require or croak "$class: unable to load $package";
-                $mods->{$package} = 1;
+                $MODS{$package} = 1;
             }
 
             # create a new object if the object doesn't exist
@@ -433,7 +438,8 @@ sub init {
 }
 
 sub get {
-    my $self = shift;
+    my ($self, $time) = @_;
+    sleep $time if $time;
     my %stat = ();
     foreach my $opt (keys %{$self->{opts}}) {
         if ($self->{opts}->{$opt}) {
